from selenium.common.exceptions import NoSuchElementException
import time

from splent_framework.environment.host import get_host_for_selenium_testing
from splent_framework.selenium.common import initialize_driver, close_driver


def test_confirmemail_index():

    driver = initialize_driver()

    try:
        host = get_host_for_selenium_testing()

        # Open the index page
        driver.get(f"{host}/confirmemail")

        # Wait a little while to make sure the page has loaded completely
        time.sleep(4)

        try:

            pass

        except NoSuchElementException:
            raise AssertionError("Test failed!")

    finally:

        # Close the browser
        close_driver(driver)


# Call the test function
test_confirmemail_index()



from locust import HttpUser, TaskSet, task
from splent_framework.environment.host import get_host_for_locust_testing


class ConfirmemailBehavior(TaskSet):
    def on_start(self):
        self.index()

    @task
    def index(self):
        response = self.client.get("/confirmemail")

        if response.status_code != 200:
            print(f"Confirmemail index failed: {response.status_code}")


class ConfirmemailUser(HttpUser):
    tasks = [ConfirmemailBehavior]
    min_wait = 5000
    max_wait = 9000
    host = get_host_for_locust_testing()
